@@ -1,9 +1,11 @@
 import json
-import numpy as np
+from typing import Any, Union
+
+import numpy as np  # type: ignore
 
 
 class NumpyEncoder(json.JSONEncoder):
-    def default(self, obj):
+    def default(self, obj: Any) -> Union[int, float, list, Any]:
         if isinstance(obj, np.integer):
             return int(obj)
         elif isinstance(obj, np.floating):
